AppsflyerAnalyticsHubProvider class
AnalyticsProvider that sends Events to Appsflyer via AppsFlyerSdk.
The provider delegates event resolution to AppsflyerEventResolver.
Customer user ID management (AppsFlyerSdk.setCustomerUserId) is handled
by the app directly on the AppsFlyerSdk instance.
Constructors
-
AppsflyerAnalyticsHubProvider({required AppsFlyerSdk appsFlyerSdk, String? name, List<
EventInterceptor> interceptors = const []}) -
Creates a provider that uses the given
appsFlyerSdkinstance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → ProviderIdentifier
-
Unique identifier identifying this provider for event routing.
finalinherited
-
interceptors
→ List<
EventInterceptor> -
Optional provider-level interceptors executed after hub interceptors.
finalinherited
- resolver → AppsflyerEventResolver
-
The resolver used by
AnalyticsHubto send events to this provider.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
flush(
) → FutureOr< void> -
Called by
AnalyticsHub.flush. Override to flush any pending events. Default implementation does nothing.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited