AppsflyerAnalyticsHubProvider class
AnalytycsProvider that sends Events to Appsflyer via AppsflyerSdk.
The provider delegates event resolution to AppsflyerEventResolver and
synchronizes Session.id with Appsflyer using
AppsflyerSdk.setCustomerUserId. When the session becomes null,
getAnonymousId is used to set an anonymous customer user ID.
Constructors
- AppsflyerAnalyticsHubProvider({required AppsflyerSdk appsFlyerSdk, String? name, required String getAnonymousId()})
-
Creates a provider that uses the given
appsFlyerSdkinstance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → ProviderIdentifier
-
Unique identifier identifying this provider for event routing.
finalinherited
-
interceptors
→ List<
EventInterceptor> -
Optional provider-level interceptors executed after hub interceptors.
finalinherited
- resolver → AppsflyerEventResolver
-
The resolver used by
AnalyticsHubto send events to this provider.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → FutureOr< void> -
Called by
AnalyticsHub.dispose. Override to clean up (e.g. close SDK). Default implementation does nothing.inherited -
flush(
) → void -
Called by
AnalyticsHub.flush. Override to flush any pending events. Default implementation does nothing. -
initialize(
) → FutureOr< void> -
Called once by
AnalyticsHub.initialize. Override to set up the backend (e.g. SDK init). Default implementation does nothing.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setSession(
Session? session) → Future< void> - Called when the current session changes (e.g. login/logout).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited